@@ -1,6 +1,6 @@
 !=======================================================================
 !
-!  PROGRAM  PHASE/0 2016.01 ($Rev: 443 $)
+!  PROGRAM  PHASE/0 2020.01 ($Rev: 599 $)
 !
 !  PROGRAM: EPSMAIN
 !
@@ -23,7 +23,7 @@
 !  Science and Technology (MEXT) of Japan. 
 !
 program EPSMAIN
-! $Id: epsmain.f90 443 2015-08-03 13:03:48Z ktagami $
+! $Id: epsmain.f90 599 2019-12-03 05:25:28Z ktagami $
 !
   implicit none
 ! === DEBUG by tkato 2013/10/16 ================================================
@@ -41,12 +41,12 @@ program EPSMAIN
   call Initialization_set_ekmode_ON  ! set `ekmode' ON in m_Control_Parameters
   call Initialization(1)             ! Initialization of mpi and file-setting
   call InputData_Analysis
-  call Preparation                   ! Basis set, symmetry check etc.
+  call Preparation(0)                ! Basis set, symmetry check etc.
   call Preparation_for_mpi(1)        ! mpi
   call PseudoPotential_Construction
   call Ewald_and_Structure_Factor    ! Calculate Structure Factor
   call Initial_Electronic_Structure()! read Charge Density, (lclchh)
-  call Initialization_Epsilon        ! Epsilon
+  call Initialization_Epsilon(0)     ! Epsilon
   call Shift_Kpoint                  ! for Effective mass calculation  ! Epsilon
 
   KPOINTS: do
